var schema = {
    criterion: {
	lcn: {
		type: 'int',
		desc: 'Logical Channel Number',
		def: "0"
	},
	duration: {
		type: 'int',
		desc: 'Recording duration (in minutes)',
		def: "0"
	},
	schedduration: {
		type: 'int',
		desc: 'Scheduled duration (in minutes)',
		def: "0"
	},
	size: {
		type: 'int',
		desc: 'Recording size (in bytes)',
		def: "0"
	},
	hour: {
		type: 'int',
		desc: 'Hour in which the recording started',
		def: "0"
	},
	age: {
		type: 'int',
		desc: 'Age (in hours)',
		def: "0"
	},
	wage: {
		type: 'int',
		desc: 'Time since last watched, or recorded (in hours)',
		def: "0"
	},
	title: {
		type: 'substr',
		desc: 'Recording Title contains',
		def: 'Enter text here...'
	},
	synopsis: {
		type: 'substr',
		desc: 'Synopsis contains',
		def: 'Enter text here...'
	},
	guidance: {
		type: 'substr',
		desc: 'Guidance Text contains',
		def: 'Enter text here...'
	},
	genre: {
		type: 'select',
		desc: 'Recording Genre',
		select: {
			Unclassified: 'Unclassified',
			Film: 'Film',
			Children: 'Children',
			'News & Factual': 'News & Factual',
			Entertainment: 'Entertainment',
			Sport: 'Sport',
			Education: 'Education',
			Lifestyle: 'Lifestyle',
			Drama: 'Drama'
		},
		def: 'Unclassified'
	},
	definition: {
		type: 'select',
		desc: 'Recording Definition',
		select: {
			SD: 'Standard Definition',
			HD: 'High Definition'
		},
		def: 'SD'
	},
	flag: {
		type: 'select',
		desc: 'Recording Flagged as',
		select: {
			Locked: 'Locked',
			New: 'New',
			Encrypted: 'Encrypted',
			Guidance: 'Guidance',
			ODEncrypted: 'Encrypted On-Disk',
			Shrunk: 'Shrunk',
			Deduped: 'De-duplicated'
		},
		def: 'New'
	},
	lock: {
		type: 'select',
		desc: 'Change Recording Lock',
		select: {
			1: 'Lock Recording',
			0: 'Unlock Recording'
		},
		def: 1
	}
    },
    action: {
	'continue': {
		'class': 'all',
		argtype: 'none',
		desc: 'Continue on to next rule',
		showcont: false
	},
	stop: {
		'class': 'all',
		argtype: 'none',
		desc: 'Do nothing and stop processing rules',
		showcont: false
	},
	move: {
		'class': 'all',
		argtype: 'folder',
		desc: 'Move recording to folder...',
		showcont: true
	},
	movecreate: {
		'class': 'all',
		argtype: 'folder',
		desc: 'Move recording to folder (creating if necessary)',
		showcont: true
	},
	fileunder: {
		'class': 'folder',
		argtype: 'folder',
		desc: 'Merge into first folder of same name found under...',
		showcont: true
	},
	fileundercreate: {
		'class': 'folder',
		argtype: 'folder',
		desc: 'Merge into or create folder of ' +
		    'same name found under...',
		showcont: true
	}
    }
};

var select_criteria = {};
$.each(schema.criterion, function(k, v) {
	select_criteria[k] = v.desc;
});

var select_file_actions = {};
var select_folder_actions = {};
$.each(schema.action, function(k, v) {
	switch (v['class'])
	{
	    case 'file':
		select_file_actions[k] = v.desc;
		break;
	    case 'folder':
		select_folder_actions[k] = v.desc;
		break;
	    case 'all':
		select_file_actions[k] = v.desc;
		select_folder_actions[k] = v.desc;
		break;
	}
});

